============================================
Xnet - Just like Xmas, but on your networks!
============================================

Xnet is a framework and a collection of command-line
tools utilizing microthreads (from the python library gevent).

All tools developed in Xnet have a common set of command-line
parameters for parallelization and other functionality,
which is provided by the framework.

Try the --help option for each tool for more details.
Reading the source code of some existing tool should
suffice to produce new tools under the same flag.

Current tools:
* tcpstate
* netcats
* resolv
* iprange
* iissn
* sslinfo
* webget
